######################################################################
#
# Spanish Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.
#
# Under the 'text macros' comments are text macros of the form:
# _macroname_ [l=es] {macro value}
# Everything between the {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textperiodicals_ [l=es] {Periódicos}
_textsource_ [l=es] {ref fuente: }
_textdate_ [l=es] {fecha de publicación: }
_textnumpages_ [l=es] {número de páginas: }

_textsignin_ [l=es] {conectarse}

_textdefaultcontent_ [l=es] {La página solicitada no fue encontrada. Por 
favor utilice el botón 'regresar' de su navegador o el botón 
de principal para regresara la Biblioteca Digital Greenstone.}

_textdefaulttitle_ [l=es] {Error en GSDL}

_collectionextra_ [l=es] {Esta colección contiene _about:numdocs_ documentos. 
La colección fue construida hace _about:builddate_ días.}

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
_collectorextra_ [l=es] {
<p>Esta colección contiene _numdocs_ _If_("_numdocs_" eq
"1",document,documents), y un total de _numbytes_.
<p><a href="_httppagex_(bsummary)">Presione aquí</a> par visualisar el
informe de construcción para esta colección.
}

_textimagecollection_ [l=es] {}
_textimageabout_ [l=es] {Página Acerca de}
_textimagehome_ [l=es] {Página Principal}
_textimagehelp_ [l=es] {Página de ayuda}
_textimagepref_ [l=es] {Página de Preferencias}
_textimagegreenstone_ [l=es] {Software de la Biblioteca Digital Greenstone}

_textimagesearch_ [l=es] {Buscar términos específicos}
_textimageTitle_ [l=es] {Navegar en las listas de títulos en orden alfabético}
_textimageList_ [l=es] {Navegar en la lista de documentos}
_textimageCreator_ [l=es] {Navegar en las listas de autores en orden alfabético}
_textimageSeries_ [l=es] {Navegar por ejemplar}
_textimageDate_ [l=es] {Navegar por fecha}
_textimageSubject_ [l=es] {Navegar por categorías de temas}
_textimageTo_ [l=es] {Navegar por campo «A»}
_textimageFrom_ [l=es] {Navegar por campo «De»}
_textimageOrganization_ [l=es] {Navegar por organización}
_textimageHowto_ [l=es] {Navegar por categorías de cómo}
_textimageTopic_ [l=es] {Navegar por tópicos especiales}
_textimageBrowse_ [l=es] {Navegar}
_textimagePeople_ [l=es] {Navegar en listas de gente en orden alfabético}
_textimageLanguage_ [l=es] {Navegar por lengua}
_textimageAcronym_ [l=es] {Navegar en la lista de siglas}
_textimagePhrase_ [l=es] {Navegar en la lista de frases}
_textimageArtist_ [l=es] {Navegar en la lista de artistas}
_textimageSource_ [l=es] {Navegar por nombre de archivo original}
_textimageKeyword_ [l=es] {Navegar por palabra clave}

_texticontabsearchgreen_ [l=es]   {Buscar}
_texticontabdategreen_ [l=es]     {Fechas}
_texticontabseriesgreen_ [l=es]   {Series}
_texticontabauthorgreen_ [l=es]   {Autores A-Z}
_texticontabtitlegreen_ [l=es]    {Títulos A-Z}
_texticontablistgreen_ [l=es]     {Listados}
_texticontabsubjectgreen_ [l=es]  {Temas}
_texticontabtogreen_ [l=es]       {A}
_texticontabfromgreen_ [l=es]     {De}
_texticontaborggreen_ [l=es]      {Organización}
_texticontabhowgreen_ [l=es]      {Cómo}
_texticontabtopicgreen_ [l=es]    {Tópicos}
_texticontabbrwsegreen_ [l=es]    {Navegar}
_texticontabbrowsgreen_ [l=es]    {Navegar}
_texticontabPeoplegreen_ [l=es]   {Gente A-Z}
_texticontabLanguagegreen_ [l=es] {Lengua}
_texticontabAcronymgreen_ [l=es]  {Siglas}
_texticontabPhrasegreen_ [l=es]   {Frases}
_texticontabArtistgreen_ [l=es]   {Artistas}
_texticontabSourcegreen_ [l=es]   {Nombres de archivos}
_texticontabKeywordgreen_ [l=es]  {Palabras claves}

_texticontext_ [l=es] {Ver el documento}
_texticonclosedbook_ [l=es] {abrir este documento y ver su índice de contenido}
_texticonnext_ [l=es] {ir a la siguiente sección}
_texticonprev_ [l=es] {ir a la sección anterior}

_texticonmidi_ [l=es] {Ver el documento en el formato MIDI}
_texticonmsword_ [l=es] {Ver el documento en el formato Microsoft Word}
_texticonpdf_  [l=es] {Ver el documento en el formato PDF}
_texticonps_  [l=es] {Ver el documento en el formato PostScript}
_texticonppt_  [l=es] {Ver el documento en el formato PowerPoint}
_texticonrtf_  [l=es] {Ver el documento en el formato RTF}
_texticonxls_  [l=es] {Ver el documento en el formato Microsoft Excel}

_page_ [l=es] {página }
_pages_ [l=es] {páginas}
_of_ [l=es] { de }
_vol_ [l=es] {Volumen}
_num_ [l=es] {número}

_textmonth00_ [l=es] {}
_textmonth01_ [l=es] {Enero}
_textmonth02_ [l=es] {Febrero}
_textmonth03_ [l=es] {Marzo}
_textmonth04_ [l=es] {Abril}
_textmonth05_ [l=es] {Mayo}
_textmonth06_ [l=es] {Junio}
_textmonth07_ [l=es] {Julio}
_textmonth08_ [l=es] {Agosto}
_textmonth09_ [l=es] {Septiembre}
_textmonth10_ [l=es] {Octubre}
_textmonth11_ [l=es] {Noviembre}
_textmonth12_ [l=es] {Diciembre}

_Document_ [l=es] {Documento}
_Section_ [l=es] {Sección}
_Paragraph_ [l=es] {Párrafo}

_magazines_ [l=es] {Revistas}

_nzdlpagefooter_ [l=es] {<p>_iconblankbar_
<p><a href="http://www.nzdl.org">Proyecto de biblioteca digital de Nueva
Zelandia</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">Departamento de informática</a>, 
<a href="http://www.waikato.ac.nz">Universidad de Waikato</a>,
Nueva Zelandia}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "PRINCIPAL" ## top_nav_button ## chome ##
_httpiconchomeof_ [l=es] {_httpimg_/es/chomeof.gif}
_httpiconchomeon_ [l=es] {_httpimg_/es/chomeon.gif}

## "AYUDA" ## top_nav_button ## chelp ##
_httpiconchelpof_ [l=es] {_httpimg_/es/chelpof.gif}
_httpiconchelpon_ [l=es] {_httpimg_/es/chelpon.gif}
   
## "PREFERENCIAS" ## top_nav_button ## cpref ##
_httpiconcprefof_ [l=es] {_httpimg_/es/cprefof.gif}
_httpiconcprefon_ [l=es] {_httpimg_/es/cprefon.gif}

## "ayuda" ## green_title ## h_help ##
_httpiconhhelp_ [l=es] {_httpimg_/es/h\_help.gif}
_widthhhelp_ [l=es] {200}
_heighthhelp_ [l=es] {57}

## "autores a-z" ## nav_bar_button ## tauth ##
_httpicontauthgr_ [l=es] {_httpimg_/es/tauthgr.gif}
_httpicontauthof_ [l=es] {_httpimg_/es/tauthof.gif}
_httpicontauthon_ [l=es] {_httpimg_/es/tauthon.gif}
_widthtauthx_ [l=es] {100}

## "series" ## nav_bar_button ## tser ##
_httpicontsergr_ [l=es] {_httpimg_/es/tsergr.gif}
_httpicontserof_ [l=es] {_httpimg_/es/tserof.gif}
_httpicontseron_ [l=es] {_httpimg_/es/tseron.gif}
_widthtserx_ [l=es] {87}

## "fechas" ## nav_bar_button ## tdate ##
_httpicontdategr_ [l=es] {_httpimg_/es/tdategr.gif}
_httpicontdateof_ [l=es] {_httpimg_/es/tdateof.gif}
_httpicontdateon_ [l=es] {_httpimg_/es/tdateon.gif}
_widthtdatex_ [l=es] {87}

## "temas" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_ [l=es] {_httpimg_/es/tsubjgr.gif}
_httpicontsubjon_ [l=es] {_httpimg_/es/tsubjon.gif}
_httpicontsubjof_ [l=es] {_httpimg_/es/tsubjof.gif}
_widthtsubjx_ [l=es] {87}

## "a" ## nav_bar_button ## tto ##
_httpiconttogr_ [l=es] {_httpimg_/es/ttogr.gif}
_httpiconttoon_ [l=es] {_httpimg_/es/ttoon.gif}
_httpiconttoof_ [l=es] {_httpimg_/es/ttoof.gif}
_widthttox_ [l=es] {87}

## "de" ## nav_bar_button ## tfrom ##
_httpicontfromgr_ [l=es] {_httpimg_/es/tfromgr.gif}
_httpicontfromon_ [l=es] {_httpimg_/es/tfromon.gif}
_httpicontfromof_ [l=es] {_httpimg_/es/tfromof.gif}
_widthtfromx_ [l=es] {87}

## "organizaciones" ## nav_bar_button ## torg ##
_httpicontorggr_ [l=es] {_httpimg_/es/torggr.gif}
_httpicontorgon_ [l=es] {_httpimg_/es/torgon.gif}
_httpicontorgof_ [l=es] {_httpimg_/es/torgof.gif}
_widthtorgx_ [l=es] {108}

## "c&oacute;mo" ## nav_bar_button ## thow ##
_httpiconthowgr_ [l=es] {_httpimg_/es/thowgr.gif}
_httpiconthowon_ [l=es] {_httpimg_/es/thowon.gif}
_httpiconthowof_ [l=es] {_httpimg_/es/thowof.gif}
_widththowx_ [l=es] {87}

## "t&oacute;picos" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_ [l=es] {_httpimg_/es/ttopicgr.gif}
_httpiconttopicon_ [l=es] {_httpimg_/es/ttopicon.gif}
_httpiconttopicof_ [l=es] {_httpimg_/es/ttopicof.gif}
_widthttopicx_ [l=es] {87}

## "navegar" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_ [l=es] {_httpimg_/es/tbrwsegr.gif}
_httpicontbrwseon_ [l=es] {_httpimg_/es/tbrwseon.gif}
_httpicontbrwseof_ [l=es] {_httpimg_/es/tbrwseof.gif}
_widthtbrwsex_ [l=es] {87}

## "navegar-meta" ## nav_bar_button ## tbrwse like above ##
_httpicontbrowsgr_ [l=es] {_httpimg_/es/tbrwsegr.gif}
_httpicontbrowson_ [l=es] {_httpimg_/es/tbrwseon.gif}
_httpicontbrowsof_ [l=es] {_httpimg_/es/tbrwseof.gif}
_widthtbrowsx_ [l=es] {87}

## "buscar" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_ [l=es] {_httpimg_/es/tsrchgr.gif}
_httpicontsrchof_ [l=es] {_httpimg_/es/tsrchof.gif}
_httpicontsrchon_ [l=es] {_httpimg_/es/tsrchon.gif}
_widthtsrchx_ [l=es] {87}

## "t&iacute;tulos a-z" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_ [l=es] {_httpimg_/es/ttitlgr.gif}
_httpiconttitlof_ [l=es] {_httpimg_/es/ttitlof.gif}
_httpiconttitlon_ [l=es] {_httpimg_/es/ttitlon.gif}
_widthttitlx_ [l=es] {90}

## "gente" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_ [l=es] {_httpimg_/es/tpeopgr.gif}
_httpicontpeopof_ [l=es] {_httpimg_/es/tpeopof.gif}
_httpicontpeopon_ [l=es] {_httpimg_/es/tpeopon.gif}
_widthtpeopx_ [l=es] {87}

## "lengua" ## nav_bar_button ## tlang ##
_httpicontlanggr_ [l=es] {_httpimg_/es/tlanggr.gif}
_httpicontlangon_ [l=es] {_httpimg_/es/tlangon.gif}
_httpicontlangof_ [l=es] {_httpimg_/es/tlangof.gif}
_widthtlangx_ [l=es] {87}

## "sigla" ## nav_bar_button ## tacro ##
_httpicontacrogr_ [l=es] {_httpimg_/es/tacrogr.gif}
_httpicontacroof_ [l=es] {_httpimg_/es/tacroof.gif}
_httpicontacroon_ [l=es] {_httpimg_/es/tacroon.gif}
_widthtacrox_ [l=es] {87}

## "frases" ## nav_bar_button ## tphrse ##
_httpicontphrsegr_ [l=es] {_httpimg_/es/tphrsegr.gif}
_httpicontphrseof_ [l=es] {_httpimg_/es/tphrseof.gif}
_httpicontphrseon_ [l=es] {_httpimg_/es/tphrseon.gif}
_widthtphrsex_ [l=es] {87}

## "artistas" ## nav_bar_button ## tartst ##
_httpicontartstgr_ [l=es] {_httpimg_/es/tartstgr.gif}
_httpicontartstof_ [l=es] {_httpimg_/es/tartstof.gif}
_httpicontartston_ [l=es] {_httpimg_/es/tartston.gif}
_widthtartstx_ [l=es] {87}

## "nombres de archivos" ## nav_bar_button ## tsrc ##
_httpicontsrcgr_ [l=es] {_httpimg_/es/tsrcgr.gif}
_httpicontsrcof_ [l=es] {_httpimg_/es/tsrcof.gif}
_httpicontsrcon_ [l=es] {_httpimg_/es/tsrcon.gif}
_widthtsrcx_ [l=es] {87}

## "palabras claves" ## nav_bar_button ## tkw ##
_httpicontkwgr_ [l=es] {_httpimg_/es/tkwgr.gif}
_httpicontkwof_ [l=es] {_httpimg_/es/tkwof.gif}
_httpicontkwon_ [l=es] {_httpimg_/es/tkwon.gif}
_widthtkwx_ [l=es] {87}

######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=es] {Acerca de esta colección}

_textsubcols1_ [l=es] {<p>La colección completa comprende _1_ subcolecciones: 
<blockquote>} 

_textsubcols2_ [l=es] {</blockquote>
Puede seleccionar (y cambiar) las subcolecciones que está
utilizando actualmente en la página de Preferencias.}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "acerca de" ## green_title ## h_about ##
_httpiconhabout_ [l=es] {_httpimg_/es/h\_about.gif}
_widthhabout_ [l=es] {200}
_heighthabout_ [l=es] {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_texticonhtitle_ [l=es] {Títulos A-Z}
_texticonhauth_ [l=es] {Autores A-Z}
_texticonhsubj_ [l=es] {Temas}
_texticonhto_ [l=es] {A}
_texticonhfrom_ [l=es] {De}
_texticonhser_ [l=es] {Series}
_texticonhdate_ [l=es] {Fechas}
_texticonhhow_ [l=es] {Cómo}
_texticonhorg_ [l=es] {Organizaciones}
_texticonhbrwse_ [l=es] {Navegar}
_texticonhbrows_ [l=es] {Browse}
_texticonhpeople_ [l=es] {Gente A-Z}
_texticonhlanguage_ [l=es] {Lenguas}
_texticonhacronym_ [l=es] {Siglas}
_texticonhphrases_ [l=es] {Frases}
_texticonhartist_ [l=es] {Artistas}
_texticonhsrc_ [l=es] {Nombres de archivos}
_texticonhkw_ [l=es] {Palabras claves}

_texticonopenbookshelf_ [l=es] {cerrar esta sección de la biblioteca}
_texticonclosedbookshelf_ [l=es] {abrir esta sección de la biblioteca y ver el índice de contenido}
_texticonopenbook_ [l=es] {cerrar este libro}
_texticonclosedfolder_ [l=es] {Abrir esta carpeta y ver su contenido}
_texticonclosedfolder2_ [l=es] {abrir subsección: }
_texticonopenfolder_ [l=es] {cerrar esta carpeta}
_texticonopenfolder2_ [l=es] {cerrar subsección: }
_texticonsmalltext_ [l=es] {Ver esta sección del texto}
_texticonsmalltext2_ [l=es] {ver texto: }
_texticonpointer_ [l=es] {sección actual}
_texticondetach_ [l=es] {Abrir esta página en una nueva ventana}
_texticonhighlight_ [l=es] {Resaltar los términos de la búsqueda}
_texticonnohighlight_ [l=es] {No resaltar los términos de la búsqueda}
_texticoncontracttoc_ [l=es] {Contraer el índice de contenido}
_texticonexpandtoc_ [l=es] {Expandir el índice de contenido}
_texticonexpandtext_ [l=es] {Mostrar el texto completo}
_texticoncontracttext_ [l=es] {Mostrar el texto sólo de la sección seleccionada}
_texticonwarning_ [l=es] {<b>Advertencia: </b>}
_texticoncont_ [l=es] {&#191;desea continuar?}

_textltwarning_ [l=es] {
<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_Expandir el texto generará una gran cantidad 
de datos a desplegar en su navegador _imagecont_
</td></tr></table></center>
}  

_textgoto_ [l=es] {ir a la página}
_textintro_ [l=es] { <i>(texto inicial)</i>}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "t&iacute;tulos a-z" ## green_title ## h_title ##
_httpiconhtitle_ [l=es] {_httpimg_/es/h\_title.gif}
_widthhtitle_ [l=es] {200}
_heighthtitle_ [l=es] {57}

## "autores a-z" ## green_title ## h_auth ##
_httpiconhauth_ [l=es] {_httpimg_/es/h\_auth.gif}
_widthhauth_ [l=es] {200}
_heighthauth_ [l=es] {57}

## "temas" ## green_title ## h_subj ##
_httpiconhsubj_ [l=es] {_httpimg_/es/h\_subj.gif}
_widthhsubj_ [l=es] {200}
_heighthsubj_ [l=es] {57}

## "a" ## green_title ## h_to ##
_httpiconhto_ [l=es] {_httpimg_/es/h\_to.gif}
_widthhto_ [l=es] { 200}
_heighthto_ [l=es] { 57}

## "de" ## green_title ## h_from ##
_httpiconhfrom_ [l=es] {_httpimg_/es/h\_from.gif}
_widthhfrom_ [l=es] { 200}
_heighthfrom_ [l=es] { 57}

## "series" ## green_title ## h_ser ##
_httpiconhser_ [l=es] {_httpimg_/es/h\_ser.gif}
_widthhser_ [l=es] {200}
_heighthser_ [l=es] {57}

## "fechas" ## green_title ## h_date ##
_httpiconhdate_ [l=es] {_httpimg_/es/h\_date.gif}
_widthhdate_ [l=es] {200}
_heighthdate_ [l=es] {57}

## "c&oacute;mo" ## green_title ## h_how ##
_httpiconhhow_ [l=es] {_httpimg_/es/h\_how.gif}
_widthhhow_ [l=es] {200}
_heighthhow_ [l=es] {57}

## "t&oacute;picos" ## green_title ## h_topic ##
_httpiconhtopic_ [l=es] {_httpimg_/es/h\_topic.gif}
_widthhtopic_ [l=es] {200}
_heighthtopic_ [l=es] {57}

## "organizaci&oacute;n" ## green_title ## h_org ##
_httpiconhorg_ [l=es] {_httpimg_/es/h\_org.gif}
_widthhorg_ [l=es] {250}
_heighthorg_ [l=es] {57}

## "navegar" ## green_title ## h_brwse ##
_httpiconhbrwse_ [l=es] {_httpimg_/es/h\_brwse.gif}
_widthhbrwse_ [l=es] {200}
_heighthbrwse_ [l=es] {57}

## "navegar-meta" ## green_title ## h_brwse like above ##
_httpiconhbrows_ [l=es] {_httpimg_/es/h\_brwse.gif}
_widthhbrows_ [l=es] { 200}
_heighthbrows_ [l=es] { 57}

## "gente" ## green_title ## h_people ##
_httpiconhpeople_ [l=es] {_httpimg_/es/h\_people.gif}
_widthhpeople_ [l=es] {200}
_heighthpeople_ [l=es] {57}

## "lenguas" ## green_title ## h_lang ##
_httpiconhlanguage_ [l=es] {_httpimg_/es/h\_lang.gif}
_widthhlanguage_ [l=es] {200}
_heighthlanguage_ [l=es] {57}

## "siglas" ## green_title ## h_acro ##
_httpiconhacronym_ [l=es] {_httpimg_/es/h\_acro.gif}
_widthhacronym_ [l=es] {200}
_heighthacronym_ [l=es] {57}

## "frases" ## green_title ## h_phrse ##
_httpiconhphrse_ [l=es] {_httpimg_/es/h\_phrse.gif}
_widthhphrse_ [l=es] {200}
_heighthphrse_ [l=es] {57}

## "artistas" ## green_title ## h_artist ##
_httpiconhartist_ [l=es] {_httpimg_/es/h\_artist.gif}
_widthhartist_ [l=es] {200}
_heighthartist_ [l=es] {57}

## "nombres de archivos" ## green_title ## h_src ##
_httpiconhsrc_ [l=es] {_httpimg_/es/h\_src.gif}
_widthhsrc_ [l=es] {200}
_heighthsrc_ [l=es] {57}

## "palabras claves" ## green_title ## h_kw ##
_httpiconhkw_ [l=es] {_httpimg_/es/h\_kw.gif}
_widthhkw_ [l=es] {200}
_heighthkw_ [l=es] {57}

## "DESEA CONTINUAR?" ## top_nav_button ## cont ##
_httpiconcontoff_ [l=es] {_httpimg_/es/contof.gif}
_httpiconconton_ [l=es] {_httpimg_/es/conton.gif}

## "    TEXTO 
COMPLETO" ## document_button ## eallt ## 
_httpiconealltof_ [l=es] {_httpimg_/es/ealltof.gif}
_httpiconeallton_ [l=es] {_httpimg_/es/eallton.gif}

## " CONTRAER 
    &Iacute;NDICE" ## document_button ## econc ##
_httpiconeconcof_ [l=es] {_httpimg_/es/econcof.gif}
_httpiconeconcon_ [l=es] {_httpimg_/es/econcon.gif}

## "SEPARAR" ## document_button ## edtch ##
_httpiconedtchof_ [l=es] {_httpimg_/es/edtchof.gif}
_httpiconedtchon_ [l=es] {_httpimg_/es/edtchon.gif}

## "EXPANDIR 
   &Iacute;NDICE" ## document_button ## eexpc ##
_httpiconeexpcof_ [l=es] {_httpimg_/es/eexpcof.gif}
_httpiconeexpcon_ [l=es] {_httpimg_/es/eexpcon.gif}

## "CONTRAER 
    TEXTO" ## document_button ## etsec ##
_httpiconetsecof_ [l=es] {_httpimg_/es/etsecof.gif}
_httpiconetsecon_ [l=es] {_httpimg_/es/etsecon.gif}

## "RESALTAR" ## document_button ## ehl ##
_httpiconehlof_ [l=es] {_httpimg_/es/ehlof.gif}
_httpiconehlon_ [l=es] {_httpimg_/es/ehlon.gif}

## "     NO 
RESALTAR" ## document_button ## enhl ##
_httpiconenhlof_ [l=es] {_httpimg_/es/enhlof.gif}
_httpiconenhlon_ [l=es] {_httpimg_/es/enhlon.gif}


######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=es] {_If_(_thislast_,resultados _thisfirst_ - _thislast_ para la petición:_cgiargq_,No se encontraron resultados para la petición: _cgiargq_)}

_textnoquerytitle_ [l=es] {Página de búsqueda}

_texticonthispage_ [l=es] {buscar}
_textsome_ [l=es] {_If_(_cgiargb_,clasificado,algunas de)}
_textall_ [l=es] {_If_(_cgiargb_,boleano,todas)}
_textformsome_ [l=es] {_If_(_cgiargb_,ranked,some)}
_textformall_ [l=es] {_If_(_cgiargb_,natural,all)}
_texticonqueryresultsbar_ [l=es] {}
_texticonsearchhistorybar_ [l=es] {historia de búsquedas}

#alt text for query buttons
_textusequery_ [l=es] {utilizar esta búsqueda}
_textfreqmsg1_ [l=es] {Palabras contadas: }
_textpostprocess_ [l=es] {_If_(_quotedquery_,<br><i>postprocesado para encontrar _quotedquery_</i>
)}					     

_textmorethan_ [l=es] {Más de }
_textapprox_ [l=es] {Acerca de }
_textnodocs_ [l=es] {No hay documentos que correspondan a la petición.}
_text1doc_ [l=es] {un documento corresponde a la petición.}
_textlotsdocs_ [l=es] {documentos corresponden a la petición.}
_textmatches_ [l=es] {Correspondencias }
_textbeginsearch_ [l=es] {Iniciar la búsqueda}
_textrunquery_ [l=es] {Ejecutar la búsqueda}
_textclearform_ [l=es] {Borrar el formulario}

#these go together in form search:
#"Word or phrase  (fold, stem)  ... in field"
_textwordphrase_ [l=es] {Palabra o frase}
_textinfield_ [l=es] {... en el campo}
_textfoldstem_ [l=es] {(mayúsculas y minúsculas, terminaciones de palabras)}

_textadvquery_ [l=es] {O tecle une búsqueda directamente:}
_textallfields_ [l=es] {Todos los campos}
_textand_ [l=es] {y}
_textor_ [l=es] {o}
_textandnot_ [l=es] {pero no}

# _hselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server some or all of them may remain unset

_textsimplesearch_ [l=es] {Buscar _If_(_hselection_, _hselection_)_If_(_jselection_,_textjselect_)_If_(_nselection_, en idioma _nselection_) 
que contengan _querytypeselection_ las palabras}

_textadvancedsearch_ [l=es] {Buscar _If_(_hselection_, _hselection_, _defaultindextext_)_If_(_jselection_,_textjselect_)_If_(_nselection_, en idioma _nselection_) 
utilizando la petición _querytypeselection_}

_textformsimplesearch_ [l=es] {Buscar_If_(_hselection_, _hselection_)
_If_(_jselection_, _textjselect_) _If_(_gselection_, at _gselection_
level) _If_(_nselection_, in _nselection_ language) que contengan
_formquerytypeselection_ de}

_textformadvancedsearch_ [l=es] {Buscar _If_(_hselection_, _hselection_,
_defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_,
at _gselection_ level)_If_(_nselection_, in _nselection_ language) y
enseñar resultados en orden _formquerytypeselection_ }

_textjselect_ [l=es] {_If_(_hselection_, de) _jselection_}

_textdatesearch_ [l=es] {Se puede buscar en esta colección documentos en un interval de
fechas, o documentos conteniendo une fecha particular. Eso es une
característica opcional de la consulta.}
_textstartdate_ [l=es] {Fecha inicial (o única):}
_textenddate_ [l=es] {Fecha de fin:}
_textbc_ [l=es] {antes de nuestra era}
_textad_ [l=es] {de nuestra era}
_textexplaineras_ [l=es] {«de nuestra era» y «antes de nuestra era» sont
alternativas para «A.D.» y «B.C.», respectivamente. Son palabras menos
cargadas de un enfoque cultural. }

_textstemon_ [l=es] { (ignorar las terminaciones de las palabras)}

_textsearchhistory_ [l=es] {Buscar en la Historia}

#text macros for search history
_textnohistory_ [l=es] {La búsqueda en la historia no está disponible}
_texthresult_ [l=es] {resultado}
_texthresults_ [l=es] {resultados}
_texthallwords_ [l=es] {todas las palabras}
_texthsomewords_ [l=es] {algunas palabras}
_texthboolean_ [l=es] {boleano}
_texthranked_ [l=es] {clasificado}
_texthcaseon_ [l=es] {tener en cuenta mayúsculas y minúsculas}
_texthcaseoff_ [l=es] {no tener en cuenta mayúsculas y minúsculas}
_texthstemon_ [l=es] {no tener en cuenta las terminaciones de las palabras}
_texthstemoff_ [l=es] {tener en cuenta las terminaciones de las palabras}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "buscar" ## green_title ## h_search ##
_httpiconhsearch_ [l=es] {_httpimg_/es/h\_search.gif}
_widthhsearch_ [l=es] {200}
_heighthsearch_ [l=es] {57}

## "resultados" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_ [l=es] {_httpimg_/es/qryresb.gif}
_widthqryresb_ [l=es] {_pagewidth_}
_heightqryresb_ [l=es] {17}

## "historia" ## green_bar_left_aligned ## schhistb ##
_httpiconsrchhistb_ [l=es] {_httpimg_/es/schhistb.gif}
_widthsrchhistb_ [l=es] {_pagewidth_}
_heightsrchhistb_ [l=es] {17}

## "mostrar" ## hand_made ##
_httpicondisplay_ [l=es] {_httpimg_/es/display.gif}
_widthdisplay_ [l=es] {60}
_heightdisplay_ [l=es] {20}

######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textprefschanged_  [l=es] {
Las preferencias son fijadas cómo sigue. No utilize el botón «retraso»
de su navegador, o no serán grabadas! En lugar de eso, clique en uno de
los botones en la barra de acceso sobre.
}
_textsetprefs_  [l=es] {fijar preferencias}
_textsearchprefs_ [l=es] {Preferencias de búsqueda}
_textcollectionprefs_ [l=es] {Preferencias de colecciones}
_textpresentationprefs_ [l=es] {Preferencias de presentación}
_textpreferences_ [l=es] {Preferencias}
_textcasediffs_ [l=es] {Reconocimiento de mayúsculas y minúsculas:}
_textignorecase_ [l=es] { ignorar diferencias entre mayúsculas y minúsculas}
_textmatchcase_ [l=es] { deben corresponder mayúsculas y minúsculas}
_textwordends_ [l=es] {Terminaciones de las palabras:}
_textstem_ [l=es] { ignorar las terminaciones de las palabras}
_textnostem_ [l=es] { debe corresponder la palabra completa}
_textprefop_ [l=es] {Regresa hasta _maxdocoption_ resultados con _hitsperpageoption_ aciertos por página.}
_textextlink_ [l=es] {Acceder a páginas de Web externas: }
_textintlink_ [l=es] {Documentos fuente recuperados de:}
_textlanguage_ [l=es] {Idioma de la interfaz: }
_textencoding_ [l=es] {Codificación: }
_textformat_ [l=es] {Formato de la interfaz: }
_textall_ [l=es] {todas}
_textquerymode_ [l=es] {Típo de búsqueda:}
_textsimplemode_ [l=es] {búsqueda simple}
_textadvancedmode_ [l=es] {búsqueda avanzada (permite búsquedas boleanas utilizando !, &, | y paréntesis)}
_textlinkinterm_ [l=es] {a través de una página intermedia}
_textlinkdirect_ [l=es] {ir directamente ahí}
_textdigitlib_ [l=es] {la biblioteca digital}
_textweb_ [l=es] {el web}
_textgraphical_ [l=es] {Gráfica}
_texttextual_ [l=es] {Sólo texto}
_textcollectionoption_ [l=es] {<p>
Subcolecciones a incluir:
<br>}

_textrelateddocdisplay_ [l=es] { mostrar documentos relacionados }
_textsearchhistory_ [l=es] { historia de búsquedas:}
_textnohistory_ [l=es] { no historia de búsquedas}
_texthistorydisplay_ [l=es] { mostrar _historynumrecords_ grabaciones de
historia de búsqueda} 
_textnohistorydisplay_ [l=es] { no mostrar la historia de búsqueda}

_texttypesearch_ [l=es] { Típo de búsqueda:}
_texttextsearch_ [l=es] { búsqueda textual}
_textformsearch_ [l=es] { búsqueda de formulario}
_textqueryboxsize_ [l=es] { Tamaño de la caja de búsqueda:}
_textregbox_ [l=es] { caja de búsqueda normal}
_textbigbox_ [l=es] { caja de búsqueda grande}
_textformtype_ [l=es] {Típo de formulario:}
_textsimple_ [l=es] { simple}
_textadvanced_ [l=es] { avanzada}

# used in "with 4 fields" in the form search box
_textwith_ [l=es] {con}
_textfields_ [l=es] {campos}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "preferencias" ## green_title ## h_pref ##
_httpiconhpref_ [l=es] {_httpimg_/es/h\_pref.gif}
_widthhpref_ [l=es] {200}
_heighthpref_ [l=es] {57}

#####################################################################
# 'browse' package for the dynamic browsing interface
package browse
#####################################################################

_textsortby_ [l=es] {Ordenar los documentos por}
_textalsoshowing_ [l=es] {enseñando también}
_textwith_ [l=es] {con un máximo de} 
_textdocsperpage_ [l=es] {documentos en cada página}

_textfilterby_ [l=es] {Buscar documentos conteniendo}
_textall_ [l=es] {todas}
_textany_ [l=es] {algunas de}
_textwords_ [l=es] {las palabras}
_textleaveblank_ [l=es] {deja esta caja vacía para obtener todos los documentos}

_browsebuttontext_ [l=es] {"Ordenar los documentos"}

_nodata_ [l=es] {<i>no datos</i>}
_docs_ [l=es] {documentos}

######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=es] {Ayuda}
_textSearchshort_ [l=es] {Buscar palabras clave}
_textSeriesshort_ [l=es] {Acceder a las publicaciones por series}
_textDateshort_ [l=es] {Acceder a las publicaciones por fecha}
_textSubjectshort_ [l=es] {Acceder a las publicaciones por tema}
_textToshort_ [l=es] {Acceder a las publicaciones por campo «A»}
_textFromshort_ [l=es] {Acceder a las publicaciones por campo «De»}
_textTitleshort_ [l=es] {Acceder a las publicaciones por título}
_textBrowseshort_ [l=es] {Navegar en las publicaciones}
_textCreatorshort_ [l=es] {Acceder a las publicaciones por autor}
_textOrganizationshort_ [l=es] {Acceder a las publicaciones por organización}
_textHowtoshort_ [l=es] {Acceder a las publicaciones por lista de cómo}
_textTopicshort_ [l=es] {Acceder a las publicaciones por tópico}
_textPeopleshort_ [l=es] {Acceder a las publicaciones por gente}
_textLanguageshort_ [l=es] {Acceder a las publicaciones por lengua}
_textAcronymshort_ [l=es] {Acceder a las publicaciones por ocurrencia de sigla}
_textPhraseshort_ [l=es] {Navegar en las frases apareciendo en la publicationes}
_textArtistshort_ [l=es] {Acceder a las publicaciones por artista}
_textSourceshort_ [l=es] {Acceder a las publicaciones por nombre de archivo}
_textKeywordshort_ [l=es] {Acceder a las publicaciones por palabra clave}
_textdefaultshorttext_ [l=es] {Clasificación no definida}

_textSearchlong_ [l=es] { <p>Puede <i>buscar palabras clave</i> que
aparecen en el texto desde la página de "búsqueda".  Ésta
es la primera página que aparece cuando usted inicia y puede ser
accesada desde otras páginas al presionar el botón de
<i>buscar</i>.  }

_textTitlelong_ [l=es] { <p>Puede <i>acceder a las publicaciones por título</i> 
presionando el botón <i>titulos a-z</i>. El resultado será una 
lista de libros en orden alfabético.  }

_textOrganizationlong_ [l=es] { <p>Puede <i>acceder a las publicaciones por 
organización</i> presionando el botón <i>organización</i>. El resultado 
será una lista de organizaciones.  }

_textHowtolong_ [l=es] { <p>Puede <i>acceder a las publicaciones por una lista 
de cómo</i> presionando el botón <i>cómo</i>. El resultado 
será una lista de cómos.  }

_textCreatorlong_ [l=es] { <p>Puede <i>acceder a publicaciones por autor</i> 
presionando el botón <i>autores a-z</i>. El resultado será una 
lista de libros ordenados por el apellido del autor.  }

_textTopiclong_ [l=es] { <p>Puede <i>acceder a las publicaciones por tópico</i> 
presionando el botón de <i>tópico</i>. El resultado será 
una lista de tópicos para navegarlos.  }

_textSubjectlong_ [l=es] { <p>Puede <i>acceder a las publicaciones por tema</i> 
presionando el botón de <i>temas</i>. El resultado será una lista de temas, 
representados por libreros.  }

_textTolong_ [l=es] { <p>Puede <i>acceder a las publicaciones por campo
«A»</i> presionando el botón <i>a</i>. El resultado será una lista de
destinarios. }

_textFromlong_ [l=es] { <p>Puede <i>acceder a las publicaciones por
campo «De»</i> presionando el botón <i>de</i>. El resultado será una
lista de remitentes. }

_textSerieslong_ [l=es] { <p>Puede <i>acceder a las publicaciones por series</i> 
presionando el botón de <i>series</i>. El resultado será una lista 
de las series que se encuentran en la colección.  }

_textDatelong_ [l=es] { <p>Puede <i>acceder a las publicaciones por fecha</i> 
presionando el botón de <i>fechas</i>. El resultado será una lista
de todas las publicaciones, ordenadas cronológicamente.  }

_textBrowselong_ [l=es] { <p> Puede <i>navegar en las publicaciones</i> presionando 
el botón de <i>navegar</i>.  }

_textPeoplelong_ [l=es] { <p>Puede <i>acceder a las publicaciones por
gente</i> presionando el botón <i>gente a-z</i>.  El resultado será una
lista ordenada por apellido.  }

_textLanguagelong_ [l=es] { <p>Puede <i>acceder a las
publicaciones por lengua</i> presionando el botón <i>lenguas</i>. 
El resultado será una lista ordenada por lengua.  }

_textAcronymlong_ [l=es] { <p>Puede <i>acceder a las
publicaciones por ocurrencia de sigla</i> presionando el botón
<i>siglas</i>.  El resultado será una lista de siglas y donde ocurren. }

_textPhraselong_ [l=es] { <p>Puede <i>navegar en las frases
apareciendo en las publicaciones</i> presionando el botón <i>frases</i>. 
Eso utilisará el navegador "phind phrase". }

_textArtistlong_ [l=es] { <p>Puede <i>acceder a las
publicaciones por artista</i> presionando el botón <i>artistas</i>.  
El resultado será una lista ordenada por nombre de artista. }

_textSourcelong_ [l=es] { <p>Puede <i>acceder a las publicaciones por
nombre de archivo</i> presionando el botón <i>nombres de archivos</i>.
El resultado será una lista ordenada por nombre de archivo original. }

_textKeywordlong_ [l=es] { <p>Puede <i>acceder a las publicaciones por
palabra clave</i> presionando el botón <i>palabras claves</i>.  El
resultado será una lista de palabras claves. }

_textdefaultlongtext_ [l=es] { <p>Pulse el botón <i>desconocido</i> para
navegar en las publicaciones (el listado será ordenado por un campo
desconocido).  }

_texthelptopics_ [l=es] {

<h2 align=left>Tópicos</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
  _topicreadingdocs_
  <li><a href="\#searching">&#191;Cómo buscar palabras clave?</a>
<ul>
  <li><a href="\#query-terms">Términos de la búsqueda</a>
  <li><a href="\#query-type">Tipo de petición</a>
  <li><a href="\#scope-of-queries">Rango de las búsquedas</a>
</ul>
  <li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">Preferencias de colección</a>
  <li><a href="\#pres-prefs">Preferencias de presentación</a>
  <li><a href="\#search-prefs">Preferencias de búsqueda</a>
</ul>
</ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_ [l=es] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_ [l=es] {&#191;Cómo leer los documentos?}
_booktextreadingdocs_ [l=es] {&#191;Cómo leer los libros?}
_bibtextreadingdocs_ [l=es] {Obtener más información sobre un elemento bibliográfico}

_texthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Puede notar cuando ha llegado a un documento en particular porque su 
título y autor aparecen en la parte superior izquierda de la 
página. Al lado de éstos está el número de la 
página actual, un cuadro que le permite seleccionar la nueva 
página y las flechas de adelante y atrás.

<p>Debajo está el texto de la sección actual. Cuando lo haya 
leido, las flechas que se encuentran en la parte inferior pueden llevarlo a la 
sección siguiente o regresarlo a la sección anterior.

<p>Abajo del título y autor se encuentran tres botones. Presione
<i>texto completo</i> para desplegar el texto completo de documento actual. 
Si el documento es extenso, este proceso tomará algún tiempo y 
utilizará mucha memoria!. Presione <i>separar</i> para crear un nueva 
ventana de su navegador para este documento (esto es útil si desea 
comparar documentos o leer dos a la vez). Finalmente, cuando realiza una 
búsqueda, las palabras a buscar aparecen resaltadas; presione <i>sin 
resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Presione la flecha para ir a la sección siguiente ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... o regresar a la sección anterior</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Desplegar el texto completo, o no</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos buscados</td></tr>
</table>
}

_booktexthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Puede notar cuando ha llegado a un libro en particular porque la 
fotografía de su portada aparece en la parte izquierda de la 
página. Al lado de la fotografía está el índice 
de contenido con una flecha que le indica dónde está usted. 
Este índice es expandible: presione las carpetas para abrirlas o 
cerrarlas. Presione en el libro abrierto, que se encuentra en la parte 
superior, para cerrarlo.

<p>Debajo está el texto de la sección actual. Cuando lo haya 
leido, las flechas que se encuentran en la parte inferior pueden llevarlo a la
sección siguiente o regresarlo a la sección anterior.

<p>Abajo de la fotografía se encuentran cuatro botones. Presione sobre 
<i>texto completo</i> para desplegar el texto completo de la sección 
actual o del libro. Si el libro es extenso, este proceso tomará 
algún tiempo y utilizará mucha memoria!. Presione <i>expandir 
índice</i> para expandir el índice completo y así pueda 
ver todos los títulos de capítulos y subsecciones. Presione 
<i>separar</i> para crear un nueva ventana de su navegador para este documento 
(esto es útil si desea comparar libros o leer dos a la vez). Finalmente, 
cuando realiza una búsqueda, las palabras a buscar aparecen resaltadas; 
presione <i>sin resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconbshelf_" border="0"></td><td>Abrir este librero</td></tr>
<tr><td><img src="_httpiconopenbook_" border="0"></td><td><img 
src="_httpiconbook_" border="0"></td><td>Abrir/cerrar este libro</td></tr>
<tr><td colspan=2><img src="_httpiconitext_" border="0"></td><td>Ver esta sección del texto</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Desplegar el texto completo, o no</td></tr>
<tr><td><img src="_document:httpiconeexpcof_" border="0"></td><td><img
src="_document:httpiconeconcof_" border="0"></td><td>Expandir o no el índice de contenido</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos de la búsqueda</td></tr>
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Presionar la flecha para ir a la sección siguiente ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... o regresar a la sección anterior</td></tr>
</table>
}

_bibtexthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Algunos elementos bibliográficos contienen más 
información, por ejemplo un resumen. Puede notar desde la página 
de resultados si este es el caso porque que se muestran con el ícono
 _icontext_ en lugar del ícono _iconblanktext_.

<p>Presionar el ícono _icontext_ le dará más 
información acerca del elemento bibliográfico.

<p> Abajo del elemento bibliográfico se encuentran dos botones. Presione
<i>separar</i> para crear un nueva ventana de su navegador para este 
libro (esto es útil si desea comparar elementos bibliográficos). 
Finalmente, cuando realiza una búsqueda, las palabras a buscar aparecen 
resaltadas; presione <i>sin resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos buscados</td></tr>
</table>
}

_texthelpsearching_ [l=es] {
<h2>&#191;Cómo buscar palabras clave?</h2>
<p>
  Desde la página de búsqueda, hacer una petición siguiendo estos pasos:<p>
  <ol><li>Especificar qué documentos quiere buscar
      <li>Decir si quiere buscar todas las palabras o sólo algunas
      <li>Escribir las palabras que quiere buscar
      <li>Presionar el botón de <i>Iniciar la búsqueda</i>
  </ol>
  
<p>Cuando hace una petición, se mostrarán los títulos de 
veinte documentos resultantes. Existe un botón al final que lo 
llevará a los siguientes veinte documentos. De ahí 
encontrará botones para llevarlo a los terceros veinte o regresar a los 
primeros veinte, etcétera. Presione el título de cualquier 
documento o el pequeño botón al lado de él, para verlo. 

<p>El número máximo documentos resultantes es de 100. Puede 
  cambiar este número presionando el botón de <i>preferencias</i>
  que se encuentra en la parte superior de la página.<p>

<p>_iconblankbar_
<a name=query-terms>
<h3>Términos de la búsqueda</h3>

<p>Lo que escribe en el cuadro de petición es interpretado como una 
lista de palabras llamadas "términos de la búsqueda". Cada 
término contiene letras y dígitos. Los términos se separan 
por el espacio en blanco. Si aparecen otros caracteres, como los de 
puntuación, éstos sirven para separar los términos 
como si fueran espacios y son ignorados. No puede buscar palabras que incluyan 
puntuación.

<p>Por ejemplo, la petición<p>
    <ul><kbd>Agro-sivicultura en las Islas del Pacífico: Sistemas de Sustento (1993)</kbd></ul>
      <p>será tratado de igual manera que<p>
      <ul><kbd>Agro sivicultura en las Islas del Pacífico Sistemas de Sustento 1993 </kbd></ul><p>
      
<p>_iconblankbar_
<a name=query-type>
<h3>Tipo de petición</h3>

<p>Existen dos tipos de petición.

<ul>
  <li>Peticiones de <b>todas</b> las palabras. Ésta busca documentos que 
      contengan todas las palabras que especifique. Los documentos que 
      satisfagan la petición serán desplegados en orden 
      alfabético. <p>     
      
  <li>Peticiones de <b>alguna(s)</b> palabra(s).  Solamente liste los
      términos que probablemente aparecerán en los documentos que 
      esté buscando. Los documentos se ordenarán de acuerdo a que 
      tanto coincidieron con su petición. Cuando se determina el grado de
      correspondencia, 

      <p><ul>
        <li> entre más términos buscados contenga el documento, 
             satisfacerá mejor su petición;
        <li> los términos no comunes son más importantes que los 
             comunes;
        <li> los documentos más pequeños tienen más 
             probabilidades que los grandes de corresponder a su solicitud.
      </ul>      
</ul>

<p>Utilice tantos términos de búsqueda como desee, una 
oración completa, o quizas todo un párrafo. Si especifica un 
sólo término, los documentos serán 
ordenados por frecuencia de ocurrencia.<p>
_texthelpscope_
}

_textdatesearch_ [l=es] {Buscar con fechas}

_texthelpdatesearch_ [l=es] {

<h2>_textdatesearch_</h2>

La búsqueda de fecha le deja encontrar documentos que, además de
corresponder a las palabras de la búsqueda, están sobre acontecimientos
dentro de un interval temporal. Usted puede buscar documentos sobre un
cierto año o entre dos años. Observe que usted no tiene que dar términos
de la búsqueda -- puede solamente buscar por la fecha solamente;  y
también usted no tiene que utilizar fechas en su búsqueda, si usted no
da ninguna fecha es justo como si no exitía la búsqueda de la fecha.<p >


<p>_iconblankbar_
<a name=datesearch-howto>
<h3> Cómo utilizar esta funcionalidad:</h3>
<ul>
   <li>Para buscar para documentos sobre un solo año: <p>
   <ul>
       <li>Dar términos ordinarios de búsqueda como se hace normalmente.

       <li>Dar el año deseado en la caja "Fecha inicial (o única):".

       <li>Si la fecha es antes de nuestra era (antes de Jesús Cristo),
         elegir la opción "antes de nuestra era" en el menu cerca de la
         caja.

       <li>Empezar la búsqueda como normalmente. 

   </ul>

<p>

  <li>Para buscar para documentos sobre un interval temporal: <p>

   <ul>

       <li>Dar términos ordinarios de búsqueda como se hace normalmente.

       <li>Dar la fecha anterior en la caja "Fecha inicial (o única):".

       <li>Dar la fecha posterio en la caja "Fecha de fin:".

       <li>Select "B.C.E from the pulldown menu next to any date from before 
           the common era (also known as before Christ).

       <li>Elegir la opción "antes de nuestra era" en el menu cerca de la
         caja de cualquiera fecha antes de nuestra era (antes de Jesús
         Cristo).

       <li>Empezar la búsqueda como normalmente. 

   </ul>    

</ul><p>

<p>_iconblankbar_
<a name=datesearch-results>
<h3>Como interpretar los resultados de las búsquedas</h3>

Generalmente una búsqueda para los documentos sobre el año 1903 no dará
los documentos que, por ejemplo, hablan de libros escritos en 1903, pero
solamente documentos sobre 1903.  Sin embargo, dará los documentos que
hablan un interval temporal (por ejemplo 1899-1911) que incluye 1903, y
también esos documentos que, como parte de su texto hablan del siglo
conteniendo el año 1903 (por ejemplo el "siglo 20" or el "siglo XX").
Esto significa que para algunos documentos, las fechas en su búsqueda no
aparecerán realmente en el texto del documento.  Para una búsqueda de un
interval temporal, todo esto se aplica a todas las fechas del
interval.<p >

}

_textchangeprefs_ [l=es] {Cambiando sus preferencias}

_texthelppreferences_ [l=es] {<h2>_textchangeprefs_</h2>

<p>Cuando presione el botón de <i>preferencias</i>, de la parte superior de la
página, será capaz de cambiar algunas características de la 
interfaz para satisfacer sus propios requisitos.

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>Preferencias de colección</h3>
<p>
Algunas colecciones se componen de varias subcolecciones, las cuales pueden
buscarse de forma independiente o juntas, como una unidad. De esta 
manera, puede seleccionar qué subcolecciones desea incluir en sus 
búsquedas en la página de preferencias.

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>Preferencias de presentación</h3>
<p>
Dependiendo de la colección, pueden existir muchas opciones para definir 
la manera de la presentación.
<p>
Las colecciones de páginas de Web le permiten eliminar la barra de 
navegación de Greenstone de la parte superior de cada página, 
de modo que una vez terminada la búsqueda se encontrará en la 
página correspondiente sin los encabezados de Greenstone. Para realizar 
otra búsqueda tendrá que utilizar el botón "regresar" de 
su navegador. Estas colecciones también le permiten eliminar el mensaje 
de alerta de Greenstone cuando seleccione una liga que lo lleve fuera de la 
colección de la biblioteca digital y de Web en si. Y en algunas 
colecciones del Web puede controlar si las ligas de la página de 
"Resultados de la búsqueda" lo llevan directo al URL en cuestión 
o más bien a la copia de la página de la biblioteca digital.

<p>
Las colecciones que son capaces de ser representadas en diferentes idiomas 
le permiten especificar el idioma de la interfaz. Si el idioma es Chino, 
puede especificar también cuáles son los estándares 
Chinos de codificación que utiliza su navegador.

<p>
Finalmente, todas las colecciones le permiten cambiar a una interfaz de texto
diferente de la gráfica. Esto es muy útil para los usuarios con 
problemas visuales que utilizan fuentes grandes o sintetizadores de voz como 
salida.

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>Preferencias de búsqueda</h3>
Dos pares de botones controlan la diferencia entre mayúsculas y 
minúsculas y las raíces de las búsquedas que hace. 
El primer conjunto de botones controla si deben coincidir mayúsculas 
o minúsculas. El segundo conjunto controla si se ignoran las 
terminaciones de las palabras o no (raíces).

<p>Por ejemplo, si los botones de <i>ignorar diferencias entre mayúsculas
y minúsculas</i> y el de <i>ignorar terminaciones de palabras</i> 
están seleccionados, la búsqueda<p>
    <ul><kbd>Construcciones Africanas</kbd></ul>
      <p>será considerada al igual que <p>
      <ul><kbd>constructores africanos</kbd></ul><p>
      porque la letra mayúscula en "Africanas" sera transformada a 
      minúscula, y los sufijos "ciones" y "nas" se eliminaran de 
      "Construcciones" y "Africanas" respectivamente ( de la misma manera, 
      "tores" y "nos" se eliminarán de "constructores" y "africanos").

<p>También puede cambiar a un modo "avanzado" de consulta que le permite 
combinar términos utilizando Y (&), O (|), y NO (!). Esto le 
permitirá especificar consultas más precisas.

<p>Finalmente, puede controlar el número de aciertos regresados, y el
número de estos presentado en cada pantalla completa.
}

_texttanumbrowseoptions_ [l=es] {Existen _numbrowseoptions_ manera(s) de encontrar información en esta colección:}

_textsimplehelpheading_ [l=es] {&#191;Cómo encontrar información?}

_texthelpscope_ [l=es] {
<p>_iconblankbar_
<a name=scope-of-queries>
<h3 align=left>Rango de las búsquedas</h3> 

<p>
En la mayoría de las colecciones puede escoger diferentes índices 
para buscar. Por ejemplo, puede haber índices por autor o título. 
También puede haber índices por capítulo o párrafo. 
Generalmente, se recupera el documento correspondiente sin importar él 
índice por el cual se busca. 
<p>Si los documentos son libros, estos aparecerán en el lugar 
predefinido.
}
