# if this file is executed, /bin/sh is used, as we don't start with #!
# this should work under ash, bash, zsh, ksh, sh style shells.

# make sure we are sourced, and not run

if test "$0" != "`echo $0 | sed s/setup\.bash//`" ; then
# if $0 contains "setup.bash" we've been run... $0 is shellname if sourced.
# One exception is zsh has an option to set it temporarily to the script name
  if test -z "$ZSH_NAME" ; then
  # we aren't using zsh
  gsdl_not_sourced=true
  fi
fi

if test -n "$gsdl_not_sourced" ; then
  echo "	Error: Make sure you source this script, not execute it. Eg:"
  echo "		$ source setup.bash"
  echo "	or"
  echo "		$ . ./setup.bash"
  echo "	not"
  echo "		$ ./setup.bash"
elif test -n "$GSDL3HOME" ; then
  echo "Your environment is already set up for Greenstone3!"
elif test ! -f setup.bash ; then
  echo "You must source the script from within the Greenstone home directory"
else
  GSDL3HOME=`pwd`
  export GSDL3HOME
  GSDL3OS=`uname -s | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz'`
  # check for running bash under cygwin
  if test "`echo $GSDL3OS | sed 's/cygwin//'`" != "$GSDL3OS" ;
  then
    GSDL3OS=windows
  fi
  export GSDL3OS

  PATH=$PATH:$GSDL3HOME/bin/script:$GSDL3HOME/bin/$GSDL3OS
  export PATH
  MANPATH=$MANPATH:$GSDL3HOME/doc/man
  export MANPATH
  CLASSPATH=$GSDL3HOME/lib/java/gsdl3.jar:$GSDL3HOME/lib/java/gdbm.jar:$GSDL3HOME/lib/java/j-gdbm.jar:$GSDL3HOME/lib/java/mgpp.jar:$GSDL3HOME/lib/java/xercesImpl.jar:$GSDL3HOME/lib/java/xmlParserAPIs.jar:$GSDL3HOME/lib/java/xindice.jar:$GSDL3HOME/lib/java/jaxp.jar:$GSDL3HOME/lib/java/soap.jar:$GSDL3HOME/lib/java/mail.jar:$GSDL3HOME/lib/java/activation.jar:$GSDL3HOME/lib/java/junit.jar:$GSDL3HOME/lib/java/jutest.jar:$GSDL3HOME/comms/tomcat/jakarta-tomcat-4.0.1/common/lib/servlet.jar
  export CLASSPATH

  LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$GSDL3HOME/lib/cpp
  export LD_LIBRARY_PATH

  echo "Your environment has successfully been set up to run Greenstone3"
fi
unset gsdl_not_sourced



