/*
 *    XMLTransformer.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

// XML classes
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;

import javax.xml.transform.stream.StreamSource;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

// other java classes
import java.io.StringReader;
import java.io.StringWriter;

/** XMLConverter - utitlity class for greenstone
 *
 * parses XML Strings into Documents, converts Nodes to Strings
 * different parsers have different behaviour - can experiment in here
 *
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 3308 $
 */
public class XMLTransformer {
  /** The transformer we're using */
  TransformerFactory t_factory_=null;
  
  /**
   * The no-arguments constructor. 
   *
   * Any exceptions thrown are caught internally
   * 
   * @return a new transformer
   * @see javax.xml.transform.TransformerFactory
   */
    public XMLTransformer() {
	try {
	    t_factory_ = TransformerFactory.newInstance();

	} catch (Exception e) {
	    System.out.println("XMLTransformer() exception "+e.getMessage());
	}
    }

 
	
  /**
   * Transform an XML document using a XSLT stylesheet
   * 
   * @param stylesheet an XSLT stylesheet
   * @param xml_in the XML to be transformed
   * @return the transformed XML
   */
    public String transform(String stylesheet, String xml_in) {
	
	try {
	    // Use the TransformerFactory to process the stylesheet Source and generate a Transformer.
	    Transformer transformer = t_factory_.newTransformer(new StreamSource(stylesheet));

	    // Use the Transformer to transform an XML Source and send the output to a Result object.
	    StringWriter output = new StringWriter();

	    transformer.transform(new StreamSource(new StringReader(xml_in)), new StreamResult(output));
	    return output.toString();
	} catch (TransformerConfigurationException e) {
	    System.err.println("XMLTransformer: couldn't create transformer object: "+e.getMessage());
	    return "";
	} catch (TransformerException e) {
	    System.err.println("XMLTransformer: couldn't transform the source: " + e.getMessage());
	    return "";
	}	
    }
}

 
