/*
 *    Collection.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.hli;

import org.nzdl.gsdl.service.*;
import org.nzdl.gsdl.corba.gsdlInterface.*;
import org.nzdl.gsdl.util.*;

// java standard library classes used
import java.io.IOException;
import java.io.Serializable;
import java.lang.Cloneable;
import java.util.Vector;
import java.util.Set;
import java.util.Iterator;
import java.util.Enumeration;
import java.util.Date;

/**
 * Class ...
 *
 * Based on algorithms in ...
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2220 $
 * @see
 * @see
 * @see
 * 
 */

public class Collection implements Cloneable, Serializable
{
  Server server = null;

  /** Collection name */
  String name = "empty collection name";
  /** Collection name */
  public String getName() { return name; };
  /** Collection name */
  public void setName(String str) { name = str; };

  /** Collection display name */
  String displayName = "empty collection display name";
  /** Collection display name */
  public String getDisplayName() { return displayName; };
  /** Collection display name */
  public void setDisplayName(String str) { displayName = str; };

  /** Collection about text */
  String aboutText = "empty about text";
  /** Collection about text */
  public String getAboutText() { return aboutText; };
  /** Collection about text */
  public void setAboutText(String str) { aboutText = str; };

  /** Beta status */
  boolean beta  = true;
  /** Beta status */
  public boolean get() { return beta; };
  /** Beta status */
  public void set(boolean str) { beta = str; };

  /** The date the collection was built */
  Date buildDate = new Date();
  /** The date the collection was built */
  public Date getBuildDate() { return buildDate; };
  /** The date the collection was built */
  public void setBuildDate(Date str) {buildDate  = str; };

  /** Docs in Collection */
  long docsInCollection = 0;
  /** Docs in Collection */
  public long getDocsInCollection() { return docsInCollection; };
  /** Docs in Collection */
  public void setDocsInCollection(long str) {docsInCollection  = str; };

  /** Words in Collection */
  long wordsInCollection  = 0;
  /** Words in Collection */
  public long getWordsInCollection() { return wordsInCollection; };
  /** Words in Collection */
  public void setWordsInCollection(long str) { wordsInCollection = str; };

  /** Bytes in Collection */
  long bytesInCollection  = 0;
  /** Bytes in Collection */
  public long getBytesInCollection() { return bytesInCollection; };
  /** Bytes in Collection */
  public void setBytesInCollection(long str) { bytesInCollection = str; };

  /** Collection Level MetaData */
  Vector collectionLevelMetadata = null;
  /** Collection Level MetaData */
  public Vector getCollectionLevelMetadata() { return collectionLevelMetadata; };
  /** Collection Level MetaData */
  public void setCollectionLevelMetadata(Vector str) { collectionLevelMetadata = str; };

  /** Building (unclear what this is ...) */
  Vector building = null;
  /** Building (unclear what this is ...) */
  public Vector getBuilding() { return building; };
  /** Building (unclear what this is ...) */
  public void setBuilding(Vector str) { building = str; };

  /** Format (unclear what this is ...) */
  Vector format = null;
  /** Format (unclear what this is ...) */
  public Vector getFormat() { return format; };
  /** Format (unclear what this is ...) */
  public void setFormat(Vector str) { format = str; };

  class NamedValue {
    String name;
    String value;
    NamedValue(String name, String value) {this.name=name;this.value=value;};
  }

  Collection(Server sever, String name, NzdlCollectionInfo info) {
    this.server = server;
    this.name = name;
    
    this.beta = info.isBeta();
    this.buildDate = new Date(info.getBuildDate()*1000);
    this.docsInCollection = info.getNumOfDocs();
    this.wordsInCollection = info.getNumOfWords();
    this.bytesInCollection = info.getNumOfBytes();

    this.collectionLevelMetadata = new Vector();
    {
      corbatext_t[] names = info.getInfo().collectionMeta.names;
      corbatext_t[] values = info.getInfo().collectionMeta.values;
      for (int i = 0; i < names.length;i++) {
	String thisname = NzdlCorbaFactory.toString(names[i]);
	String thisvalue = NzdlCorbaFactory.toString(values[i]);
	if (thisname == "collectionname")
	  displayName = thisvalue;
	if (thisname == "collectionextra")
	  aboutText = thisvalue;
	this.collectionLevelMetadata.add(new NamedValue(thisname,thisvalue));
	System.err.println("Metadata: \"" + thisname + "\" = \"" + thisvalue + "\"");
      }
    }
    this.building  = new Vector();
    {
      corbatext_t[] names = info.getInfo().building.names;
      corbatext_t[] values = info.getInfo().building.values;
      for (int i = 0; i < names.length;i++) {
	String thisname = NzdlCorbaFactory.toString(names[i]);
	String thisvalue = NzdlCorbaFactory.toString(values[i]);
	this.building.add(new NamedValue(thisname,thisvalue));
	System.err.println("Building: \"" + thisname + "\" = \"" + thisvalue + "\"");
      }
    }
    this.format = new Vector();
    {
      corbatext_t[] names = info.getInfo().format.names;
      corbatext_t[] values = info.getInfo().format.values;
      for (int i = 0; i < names.length;i++) {
	String thisname = NzdlCorbaFactory.toString(names[i]);
	String thisvalue = NzdlCorbaFactory.toString(values[i]);
	this.format.add(new NamedValue(thisname,thisvalue));
	System.err.println("Format: \"" + thisname + "\" = \"" + thisvalue + "\"");
      }
    }
  }



  /**
   * Tests...
   *
   * 
   * @exception java.io.IOException when ...
   * @param args the arguments ...
   */

  public static void main(String args[]) throws IOException
  {
  }
}

