/*
 *    NzdlDocSaveWrapper.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

//the package we're in
package org.nzdl.gsdl.service;

import java.io.File;
import java.io.FileWriter;

/* gsdl corba stuff */
import org.nzdl.gsdl.corba.gsdlInterface.corbaFilterRequest;
import org.nzdl.gsdl.util.NzdlCorbaFactory;

/**
 *  A Wrapper around an NzdlService object that adds functionality. 
 *
 * Typically one or more of the methods will be overridden to 
 * add that functionality
 *
 * @author Brett Sheeran (bsheeran@xtra.co.nz) (comments)
 * @author Stuart Yeates  (say1@cs.waikato.ac.nz)
 * @version $Revision: 2157 $
 */
public class NzdlDocSaveWrapper
  extends NzdlWrapper {

  static String dirPath = "/tmp/docs/";

  /**
   * The bean constructor ...
   */  
  public NzdlDocSaveWrapper() {
  }

  /**
   * The normal constructor ...
   */  
  public NzdlDocSaveWrapper(NzdlService service) {
    super(service);
    try {
      File directory = new File(dirPath);
      if (!directory.exists())
	directory.mkdirs();
    }  catch (Exception exception) {
      System.err.println("unable to create directory: " + exception);
    } 
  }
  
  /**
   * Wraps a getDocument and saves to disk any documents we see ...
   * @see NzdlService#getDocument
   */
  public String getDocument( String _name, String _docID ) {
    
    String doc =  super.getDocument(_name,_docID);
    
    try {
      File dir = new File(dirPath, _name);
      if (!dir.exists())
	dir.mkdirs();
      File file = new File(dir, _docID);
      if (!file.exists()) {
	FileWriter writer = new FileWriter(file);
	writer.write("<gsdlsection>");
	writer.write(doc);
	writer.write("</gsdlsection>");
	writer.flush();
	writer.close();
      }
    } catch (Exception exception) {
      System.err.println("Exception: " + exception);
    } 
    
    return doc;
  }

}
